# Changelog

## [1.1.7](https://github.com/lukapecnik/niaaml/tree/1.1.7) (2022-02-21)

[Full Changelog](https://github.com/lukapecnik/niaaml/compare/1.1.6...1.1.7)

**Closed issues:**

- Update to the latest niapy stable release [\#62](https://github.com/lukapecnik/NiaAML/issues/62)
- Example file pipeline.ppln is out of date [\#60](https://github.com/lukapecnik/NiaAML/issues/60)
- np.int is a deprecated alias [\#56](https://github.com/lukapecnik/NiaAML/issues/56)
- Remove setup.py file [\#54](https://github.com/lukapecnik/NiaAML/issues/54)

**Merged pull requests:**

- Update niapy [\#64](https://github.com/lukapecnik/NiaAML/pull/64) ([lukapecnik](https://github.com/lukapecnik))
- Update README.md [\#63](https://github.com/lukapecnik/NiaAML/pull/63) ([firefly-cpp](https://github.com/firefly-cpp))
- Eschew deprecated numpy aliases for builtins [\#61](https://github.com/lukapecnik/NiaAML/pull/61) ([musicinmybrain](https://github.com/musicinmybrain))
- Corrected dependencies in CONTRIBUTING [\#59](https://github.com/lukapecnik/NiaAML/pull/59) ([firefly-cpp](https://github.com/firefly-cpp))
- Do not install text files in site-packages/ [\#58](https://github.com/lukapecnik/NiaAML/pull/58) ([musicinmybrain](https://github.com/musicinmybrain))
- Use the latest upstream's release for niapy [\#57](https://github.com/lukapecnik/NiaAML/pull/57) ([firefly-cpp](https://github.com/firefly-cpp))
- Add reference links [\#55](https://github.com/lukapecnik/NiaAML/pull/55) ([firefly-cpp](https://github.com/firefly-cpp))
- Add link to the API [\#53](https://github.com/lukapecnik/NiaAML/pull/53) ([firefly-cpp](https://github.com/firefly-cpp))

## [1.1.6](https://github.com/lukapecnik/niaaml/tree/1.1.6) (2021-06-27)

[Full Changelog](https://github.com/lukapecnik/niaaml/compare/1.1.5...1.1.6)

**Closed issues:**

- Upgrade to the latest niapy release [\#51](https://github.com/lukapecnik/NiaAML/issues/51)

**Merged pull requests:**

- Update to the latest niapy version and fix docs build warnings [\#52](https://github.com/lukapecnik/NiaAML/pull/52) ([zStupan](https://github.com/zStupan))

## [1.1.5](https://github.com/lukapecnik/niaaml/tree/1.1.5) (2021-06-01)

[Full Changelog](https://github.com/lukapecnik/niaaml/compare/1.1.4...1.1.5)

**Merged pull requests:**

- Citation details [\#50](https://github.com/lukapecnik/NiaAML/pull/50) ([firefly-cpp](https://github.com/firefly-cpp))

## [1.1.4](https://github.com/lukapecnik/niaaml/tree/1.1.4) (2021-05-24)

[Full Changelog](https://github.com/lukapecnik/niaaml/compare/1.1.3...1.1.4)

**Closed issues:**

- Unable to install with conda [\#47](https://github.com/lukapecnik/NiaAML/issues/47)

## [1.1.3](https://github.com/lukapecnik/niaaml/tree/1.1.3) (2021-05-23)

[Full Changelog](https://github.com/lukapecnik/niaaml/compare/1.1.2...1.1.3)

## [1.1.2](https://github.com/lukapecnik/niaaml/tree/1.1.2) (2021-05-19)

[Full Changelog](https://github.com/lukapecnik/niaaml/compare/1.1.1...1.1.2)

**Merged pull requests:**

- Update niapy dependency [\#49](https://github.com/lukapecnik/NiaAML/pull/49) ([lukapecnik](https://github.com/lukapecnik))

## [1.1.1](https://github.com/lukapecnik/niaaml/tree/1.1.1) (2021-03-09)

[Full Changelog](https://github.com/lukapecnik/niaaml/compare/1.1.1rc2...1.1.1)

**Merged pull requests:**

- logo \[ci skip\] [\#48](https://github.com/lukapecnik/NiaAML/pull/48) ([lukapecnik](https://github.com/lukapecnik))
- Fedora package pushed to stable [\#46](https://github.com/lukapecnik/NiaAML/pull/46) ([firefly-cpp](https://github.com/firefly-cpp))
- Restructuring of paper and editorial changes [\#45](https://github.com/lukapecnik/NiaAML/pull/45) ([adi3](https://github.com/adi3))
- Corrections of paper [\#44](https://github.com/lukapecnik/NiaAML/pull/44) ([firefly-cpp](https://github.com/firefly-cpp))

## [1.1.1rc2](https://github.com/lukapecnik/niaaml/tree/1.1.1rc2) (2020-12-22)

[Full Changelog](https://github.com/lukapecnik/niaaml/compare/1.1.1rc1...1.1.1rc2)

## [1.1.1rc1](https://github.com/lukapecnik/niaaml/tree/1.1.1rc1) (2020-12-22)

[Full Changelog](https://github.com/lukapecnik/niaaml/compare/1.1.0...1.1.1rc1)

**Merged pull requests:**

- Original NiaAML method support \[ci skip\] [\#43](https://github.com/lukapecnik/NiaAML/pull/43) ([lukapecnik](https://github.com/lukapecnik))

## [1.1.0](https://github.com/lukapecnik/niaaml/tree/1.1.0) (2020-12-16)

[Full Changelog](https://github.com/lukapecnik/niaaml/compare/1.0.0rc7...1.1.0)

## [1.0.0rc7](https://github.com/lukapecnik/niaaml/tree/1.0.0rc7) (2020-12-14)

[Full Changelog](https://github.com/lukapecnik/niaaml/compare/1.0.0rc6...1.0.0rc7)

**Closed issues:**

- References [\#40](https://github.com/lukapecnik/NiaAML/issues/40)

**Merged pull requests:**

- Paper update [\#42](https://github.com/lukapecnik/NiaAML/pull/42) ([firefly-cpp](https://github.com/firefly-cpp))
- minor corrections in examples [\#39](https://github.com/lukapecnik/NiaAML/pull/39) ([firefly-cpp](https://github.com/firefly-cpp))

## [1.0.0rc6](https://github.com/lukapecnik/niaaml/tree/1.0.0rc6) (2020-12-12)

[Full Changelog](https://github.com/lukapecnik/niaaml/compare/1.0.0rc5...1.0.0rc6)

**Closed issues:**

- Conda package [\#34](https://github.com/lukapecnik/NiaAML/issues/34)

**Merged pull requests:**

- Additional features [\#38](https://github.com/lukapecnik/NiaAML/pull/38) ([lukapecnik](https://github.com/lukapecnik))
- Conda fix \[ci skip\] [\#37](https://github.com/lukapecnik/NiaAML/pull/37) ([lukapecnik](https://github.com/lukapecnik))
- Orcid identifiers added [\#36](https://github.com/lukapecnik/NiaAML/pull/36) ([firefly-cpp](https://github.com/firefly-cpp))

## [1.0.0rc5](https://github.com/lukapecnik/niaaml/tree/1.0.0rc5) (2020-12-11)

[Full Changelog](https://github.com/lukapecnik/niaaml/compare/1.0.0rc4...1.0.0rc5)

**Closed issues:**

- Installation problems [\#31](https://github.com/lukapecnik/NiaAML/issues/31)

**Merged pull requests:**

- Conda support [\#35](https://github.com/lukapecnik/NiaAML/pull/35) ([lukapecnik](https://github.com/lukapecnik))

## [1.0.0rc4](https://github.com/lukapecnik/niaaml/tree/1.0.0rc4) (2020-12-10)

[Full Changelog](https://github.com/lukapecnik/niaaml/compare/1.0.0rc3...1.0.0rc4)

**Merged pull requests:**

- Python 3.6 support [\#33](https://github.com/lukapecnik/NiaAML/pull/33) ([lukapecnik](https://github.com/lukapecnik))
- First version of paper [\#32](https://github.com/lukapecnik/NiaAML/pull/32) ([firefly-cpp](https://github.com/firefly-cpp))

## [1.0.0rc3](https://github.com/lukapecnik/niaaml/tree/1.0.0rc3) (2020-12-10)

[Full Changelog](https://github.com/lukapecnik/niaaml/compare/1.0.0rc2...1.0.0rc3)

## [1.0.0rc2](https://github.com/lukapecnik/niaaml/tree/1.0.0rc2) (2020-12-08)

[Full Changelog](https://github.com/lukapecnik/niaaml/compare/1.0.0rc1...1.0.0rc2)

**Merged pull requests:**

- feature missing values imputation [\#30](https://github.com/lukapecnik/NiaAML/pull/30) ([lukapecnik](https://github.com/lukapecnik))
- README updated [\#29](https://github.com/lukapecnik/NiaAML/pull/29) ([firefly-cpp](https://github.com/firefly-cpp))
- Readme update, encoder check for type int64 [\#28](https://github.com/lukapecnik/NiaAML/pull/28) ([lukapecnik](https://github.com/lukapecnik))
- Markdown and docs [\#27](https://github.com/lukapecnik/NiaAML/pull/27) ([lukapecnik](https://github.com/lukapecnik))

## [1.0.0rc1](https://github.com/lukapecnik/niaaml/tree/1.0.0rc1) (2020-12-06)

[Full Changelog](https://github.com/lukapecnik/niaaml/compare/0.1.4...1.0.0rc1)

**Merged pull requests:**

- Added support for categorical features [\#26](https://github.com/lukapecnik/NiaAML/pull/26) ([lukapecnik](https://github.com/lukapecnik))

## [0.1.4](https://github.com/lukapecnik/niaaml/tree/0.1.4) (2020-12-05)

[Full Changelog](https://github.com/lukapecnik/niaaml/compare/0.1.3...0.1.4)

**Merged pull requests:**

- remove 10-fold cross validation from benchmark, critical bug fix [\#25](https://github.com/lukapecnik/NiaAML/pull/25) ([lukapecnik](https://github.com/lukapecnik))
- run all experiments at once [\#24](https://github.com/lukapecnik/NiaAML/pull/24) ([firefly-cpp](https://github.com/firefly-cpp))

## [0.1.3](https://github.com/lukapecnik/niaaml/tree/0.1.3) (2020-12-04)

[Full Changelog](https://github.com/lukapecnik/niaaml/compare/0.1.3a1...0.1.3)

## [0.1.3a1](https://github.com/lukapecnik/niaaml/tree/0.1.3a1) (2020-12-01)

[Full Changelog](https://github.com/lukapecnik/niaaml/compare/0.1.2...0.1.3a1)

**Merged pull requests:**

- 0.1.3a1 pre-release python 3.7 compatibility [\#23](https://github.com/lukapecnik/NiaAML/pull/23) ([lukapecnik](https://github.com/lukapecnik))
- Fixes and additions [\#22](https://github.com/lukapecnik/NiaAML/pull/22) ([lukapecnik](https://github.com/lukapecnik))

## [0.1.2](https://github.com/lukapecnik/niaaml/tree/0.1.2) (2020-11-30)

[Full Changelog](https://github.com/lukapecnik/niaaml/compare/0.1.2a1...0.1.2)

**Implemented enhancements:**

- On the use of unittest [\#2](https://github.com/lukapecnik/NiaAML/issues/2)

**Closed issues:**

- Description of examples [\#16](https://github.com/lukapecnik/NiaAML/issues/16)

**Merged pull requests:**

- readme.rst fix, pipeline fix [\#21](https://github.com/lukapecnik/NiaAML/pull/21) ([lukapecnik](https://github.com/lukapecnik))
- Travis ci integration [\#20](https://github.com/lukapecnik/NiaAML/pull/20) ([lukapecnik](https://github.com/lukapecnik))
- badges and readme update [\#19](https://github.com/lukapecnik/NiaAML/pull/19) ([lukapecnik](https://github.com/lukapecnik))

## [0.1.2a1](https://github.com/lukapecnik/niaaml/tree/0.1.2a1) (2020-11-29)

[Full Changelog](https://github.com/lukapecnik/niaaml/compare/0.1.1...0.1.2a1)

**Closed issues:**

- Information about hyperparameter tuning [\#15](https://github.com/lukapecnik/NiaAML/issues/15)
- CHANGELOG [\#14](https://github.com/lukapecnik/NiaAML/issues/14)
- Examples [\#13](https://github.com/lukapecnik/NiaAML/issues/13)

**Merged pull requests:**

- Unittests, examples' description, references added to docs [\#17](https://github.com/lukapecnik/NiaAML/pull/17) ([lukapecnik](https://github.com/lukapecnik))

## [0.1.1](https://github.com/lukapecnik/niaaml/tree/0.1.1) (2020-11-28)

[Full Changelog](https://github.com/lukapecnik/niaaml/compare/0.1.0...0.1.1)

**Closed issues:**

- Installation instructions [\#11](https://github.com/lukapecnik/NiaAML/issues/11)

**Merged pull requests:**

- Contributors table added [\#12](https://github.com/lukapecnik/NiaAML/pull/12) ([lukapecnik](https://github.com/lukapecnik))

## [0.1.0](https://github.com/lukapecnik/niaaml/tree/0.1.0) (2020-11-27)

[Full Changelog](https://github.com/lukapecnik/niaaml/compare/fbf47d71adb6ba72aa9210e4ead316b318253862...0.1.0)

**Implemented enhancements:**

- CSV Data Reader class [\#3](https://github.com/lukapecnik/NiaAML/issues/3)

**Closed issues:**

- A non-functional demo could be written [\#4](https://github.com/lukapecnik/NiaAML/issues/4)

**Merged pull requests:**

- Framework improvements, docs initialization and readme [\#10](https://github.com/lukapecnik/NiaAML/pull/10) ([lukapecnik](https://github.com/lukapecnik))
- Pipeline methods implementation [\#9](https://github.com/lukapecnik/NiaAML/pull/9) ([lukapecnik](https://github.com/lukapecnik))
- Pipeline optimizer progress [\#8](https://github.com/lukapecnik/NiaAML/pull/8) ([lukapecnik](https://github.com/lukapecnik))
- Implementation of jDEFSTH algorithm for feature selection [\#7](https://github.com/lukapecnik/NiaAML/pull/7) ([firefly-cpp](https://github.com/firefly-cpp))
- refactoring and variance threshold feature selection implementation [\#6](https://github.com/lukapecnik/NiaAML/pull/6) ([lukapecnik](https://github.com/lukapecnik))
- NiaPy dependency added [\#5](https://github.com/lukapecnik/NiaAML/pull/5) ([firefly-cpp](https://github.com/firefly-cpp))



\* *This Changelog was automatically generated by [github_changelog_generator](https://github.com/github-changelog-generator/github-changelog-generator)*
